=======
History
=======

0.1.0 (2020-08-06)
------------------

* First release on PyPI.

0.1.1 (2020-08-06)
------------------

* Continuous integration setup

0.1.2 (2020-08-07)
------------------

* Added functionality to featurize guides

0.1.3 (2020-09-11)
------------------

* Added pam interaction feature

0.2.0 (2021-04-13)
------------------

* Added PolyN feature
* Added Tm guide feature
* Removed return values from feature dict functions
* Remove comma from Tm feature names

1.0.0 (2021-06-01)
------------------

* Change DNA hybridization calculation to RNA/DNA hybridization for guide sequence

1.1.0 (2021-06-04)
------------------

* Use RNA/DNA and DNA/DNA melting temperatures
